@@ -283,68 +283,50 @@ sub on_apply_clicked 	{ my ($b, $self) = @_; $self->{log}->debug("in Wx_dnav...\
 
 
 sub show_tables {
-	my ($self, $sql, $schema) = @_;
+	my $self= shift;
+	my %arg = @_;
 	#my $dbh = $self->{globals}->{connections}->{dbh};
-	my $dbh = $schema->storage->dbh;
-	my  $sth = $dbh->prepare($sql);	
+	if ($arg{schema}) {
+	      $arg{dbh} = $arg{schema}->storage->dbh;
+	 }
+	my  $sth = $arg{dbh}->prepare($arg{sql});	
 	$sth->execute;
 	#my $menu = Wx::Window::FindWindowById( Wx::XmlResource::GetXRCID('m_menubar1'), $self->{frame});
 	my $menubar = $self->{frame}->GetMenuBar;
 	# print $menubar->FindMenu('Table');
 	my $menu = $menubar->GetMenu($menubar->FindMenu('Table'));
 	# die Dumper( $menu );
-	my $id = 1;
+
 	while (my @row = $sth->fetchrow_array()){
 		$self->{log}->debug(" menu table: ".  $row[0]);
-		#my $t = Gtk2::MenuItem->new($row[0]);
-		my $t = $menu->Append($id, $row[0]); 
-		EVT_MENU( $self->{frame}, $id,  sub {display_tbl($self, {name => $row[0], schema => $schema} );});
-		# push @tbl, $t
-		$id++;
-		#$t->show;
+		EVT_MENU( $self->{frame},  $menu->Append(-1, $row[0]) ,  sub {display_tbl($self, name => $row[0],  dbh=> $arg{dbh}, mibuilder=>$arg{mibuilder}  );});
 	}
 
 
 }
 
 sub display_tbl {
-my ($self, $href) = @_;
+my $self = shift;
+  my  %arg = @_;
 
-	my %class = (speaks => 'Speak', langues => 'Langue', countries =>'Country');
+    #my %class = (speaks => 'Speak', langues => 'Langue', countries =>'Country');
 
 	my $data;
-	if ($href->{name}){
-		my $name = $class{ $href->{name} };
-		my $rs = $href->{schema}->resultset($name)->search_rs();
-		#$rs_def = {dbh =>$dbh,sql=> {	select => "*", from => $href->{name}},	treeview =>  $treeview	}
-		$data =  Gtk2::Ex::DbLinker::DbcDataManager->new({rs => $rs });
+	if ($arg{name}){
+		#my $name = $class{ $href->{name} };
+		#my $rs = $href->{schema}->resultset($name)->search_rs();
+		#$data =  Gtk2::Ex::DbLinker::DbcDataManager->new({rs => $rs });
+		$data = $arg{mibuilder}->(%arg);
 	} 
-=for comment
-	elsif ($href->{sql}){
-		#$rs_def = { dbh => $dbh,sql=> {	pass_through => $href->{sql}},	treeview => $treeview}
-		$data = Gtk2::Ex::DbLinker::DbiDataManager->new( $href);
-		
-	}
-=cut
 	my $f = Wx_dnav->new({ismain=>1, size=> $self->{size},  main_name=>'mainwindow', main_file=>'../xrc/main.xrc'});
 	$f->load_panel('mainwindow', 'xrc/nav.xrc', 'm_dnav_panel' );
-	#my $scroll = Gtk2::ScrolledWindow->new;
-=for comment
-	my $grid = $f->load_grid($f->{frame}, "m_panel_for_content",
- 		sub{ unshift @_, 'Wxdatasheet'; goto &{$_[0]->can('new') }}, { data_manager => $data, });
-=cut
+
 	my $param = {top_panel=>$f->{frame}, dest_name=>"m_panel_for_content", datasheet_param=>{ data_manager => $data, }};
+
 	my $grid = $f->load_grid($param);
 	$f->show_all_except([qw(m_menubar1 lbl_RecordCount RecordSpinner lbl_RecordStatus)]);
 	$f->set_form($grid);
-=for comment
- Wx::MessageBox(  
-            "Displaying table",      # text  
-            "Caption",   # title bar  
-            wxOK,        # buttons to display on form  
-            $self->{frame}        # parent  
-    );  
-=cut
+
 }
 
 sub show_querries {
@@ -354,16 +336,7 @@ sub show_querries {
 	my $mb = $self->{frame}->GetMenuBar;
 	my $menu =  $mb->GetMenu($mb->FindMenu('Querries'));
 	die unless($menu);
-	my $id = 1;
  	foreach my $n (@$i){
-	     # foreach my $v (keys %$n){
-	     # print "$v ", $n->{$v}, "\n";
-		# print $row[0],"\n";
-		#my $t = Wx::MenuItem->new($n->{menu});
-		$menu->Append($id, $n->{menu}) ;#, $n->{comment});
-		#si pk est dans les paramtres du fichier querries.txt le parametre sql ne contient que la liste des champs
-		#et les valeurs de from, where, order_by sont passees aussi
-		#sinon c'est le contenu de pass_through
 		my $href;
 		if ($n->{pk}) {
 			$self->{log}->debug("pk ", $n->{pk});
@@ -374,7 +347,7 @@ sub show_querries {
 			$href = {dbh => $dbh, sql=> {pass_through => $n->{sql}}};
 		}
 		
-		EVT_MENU( $self->{frame}, $id,  sub {display_tbl($self, $href );});
+		EVT_MENU( $self->{frame}, $menu->Append(-1, $n->{menu}),  sub {display_tbl($self, $href );});
 	 }
 
 }
