@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 
-our $VERSION     = '0.005';
+our $VERSION     = '0.006';
 $VERSION = eval $VERSION;
 
 1;
@@ -34,12 +34,13 @@ On windows use nmake or dmake instead of make.
 
 The following modules are required in order to use Wx::Perl::Linker
 
-	Gtk2::Ex::DbLinker::DbTools => 0.1,
+	Gtk2::Ex::DbLinker::DbTools => 0.105,
 	Data::Dumper => 2.154,
 	DateTime::Format::Strptime => 1.5,
 	Test::More => 1,
 	Wx => 0.99,
 	Log::Log4perl => 1.41
+	DBD::SQLite'	=> 1.46
 
 Install one of Rose::DB::Object or DBIx::Class if you want to use these orm to access your data.
 
@@ -73,9 +74,14 @@ Connect the buttons to methods that handle common actions such as inserting, mov
 
 =back
 
-=head1 EXAMPLE
+=head1 EXAMPLES
 
-The eg folder (located in the Wx-Perl-DbLinker-xxx folder under cpan/build in your perl folders tree) contains one example that use a sqlite database of three tables: 
+The eg folder (located in the Wx-Perl-DbLinker-xxx folder under cpan/build in your perl folders tree) contains three examples.
+All displays a main form with a bottom navigation bar that displays each record (a country and its main language) one by one. 
+A subform displays other(s) language(s) spoken in that country. Each language is displayed one by one and a second navigation bar is used to show these in turn.
+For each language, a list gives the others countries where this idiom is spoken. Items from this lists are also add/delete/changed with a third navigation bar.
+
+The data is stored in two sqllite files that differs only on the layout of the speaks table. In both files, there are three tables: 
 
 =over
 
@@ -89,7 +95,9 @@ langues (langid, langue),
 
 =item *
 
-speaks (langid, countryid) file ./data/ex1_1
+speaks (in file ./data/ex1_1) (langid, countryid) is access with runexample_dbc.pl, runexample_sqla.pl  
+
+speaks (in file ./data/ex1) (speaksid, langid, countryid) is access with runexample_rdb.pl
 
 =back
 
@@ -97,15 +105,15 @@ speaks (langid, countryid) file ./data/ex1_1
 
 =item *
 
-C<runeexample_dbc.pl> gives a main form with a bottom navigation bar that displays each record (a country and its main language) one by one. 
-
-A subform displays other(s) language(s) spoken in that country. Each language is displayed one by one and a second navigation bar is used to show these in turn.
-
-For each language, a list gives the others countries where this idiom is spoken. Items from this lists are also add/delete/changed with a third navigation bar.
+C<runexample_dbc.pl> uses DBIx::Class and Gtk2::Ex::DbLinker::DbcDataManager. The speaks table primary key is the complete row itself, with the two fields, countryid and langid.
 
 =item *
 
-C<runeexample_dbc.pl> uses DBIx::Class. The speaks table primary key is the complete row itself, with the two fields, countryid and langid.
+C<runexample_sqla.pl uses SQL::Abstract::More and Gtk2::Ex::DbLinker::SqlADataManager. The database is the same as above.
+
+=item *
+
+C<runexample_rdb.pl> uses Rose::Data::Object and Gtk2::Ex::DbLinker::RdbDataManager. The speaks table primary key is a counter speaksid and the two fields, countryid and langid compose an index which does not allow duplicate rows.
 
 =back
 
