@@ -89,6 +89,7 @@ sub new {
 	EVT_GRID_SELECT_CELL($self, sub{ shift->_cell_clicked( @_); });
 	EVT_GRID_RANGE_SELECT($self, sub { shift->_row_selected(@_); } );	
 	$self->{log}->debug("constructor done: rows: ". $self->GetNumberRows);
+	$self->{changed}=0;
 	return $self;
 
 }
@@ -639,7 +640,7 @@ sub delete {
 sub has_changed{
 	my $self = shift;
 	#there is no child datasheet or child form in a datasheet (or ?)
-	return ($self->{changed} ? 1 : 0);
+	return $self->{changed};
 }
 
 
