@@ -550,25 +550,18 @@ sub delete {
 
 sub apply{
 	my $self = shift;
+	my $pkref = ( defined $_[0] ? $_[0] : undef );
 	my $row;
-	my $done;
+	my $done=1;  # by default, changes are done 
 	#we are adding a new record if $pos < 0
 	$self->{log}->debug("apply: pos : " . $self->{pos} );
 	if ($self->{pos}<0){
-		#my $class =  $self->{class};
-		#$row = $class->new;
-		#$self->{dman}->new_row;
-			#push @{$self->{data}}, $row;
-			 # $self->{count} ++;
 		 $self->{log}->debug("New row");
-		 # $self->{dman}->set_row_pos($self->{dman}->row_count);
-		
 	}
 
 	# deleting a (or some) record	
 	for my $p (@{$self->{pos2del}}){
 		$self->{dman}->set_row_pos($p);
-
 		$self->{dman}->delete;
 
 	}
@@ -579,6 +572,7 @@ sub apply{
 		# $self->set_record_status_label;
 		#$self->{rec_spinner}->SetValue(1) if ($self->{rec_spinner});
 		my $last = $self->{dman}->row_count;
+		$self->{log}->debug("delelte - last pos ", $last);
 		if ($last > 0) {
 			$self->{rec_spinner}->SetValue(1) if ($self->{rec_spinner});
 			$self->_display_data(0);
@@ -587,27 +581,75 @@ sub apply{
 		}
 		return;
 	}
+	my $count = $self->_update_fields( $pkref );
+	#die $count;
+      	# return value: number of fields updated - don't save if there are none
+	if ( $count ) {
+		$self->{log}->debug("dman->save");
+		$done = $self->{dman}->save;
+	}
+ 
+	# $self->{log}->debug("nofm: " . $row->nofm);
+	# $self->set_rs_range;
+
+	#if we were adding a row, put it at the end of the array, and display all the values in the form
+	#ie the value from the user or default value from the database.
+	my %pk_val;	
+ 	my @pk =$self->{dman}->get_autoinc_primarykeys;
+
+	for my $pk (@pk) {
+		my $value = $self->{dman}->get_field($pk);
+		$pk_val{$pk} = $value;
+		$self->{log}->debug("Primary Key: " . $pk . " value : " . $value);
+	}
+			#push @pk_val, $id
+		
+	if ($done && $self->{after_insert}){
+		my $coderef = $self->{after_insert};
+		&$coderef(undef, \%pk_val );
+	}
+
+	#if ($done && $self->{pos}<0){
+	if ($done && $self->{inserting}){
+		my $last = $self->{dman}->row_count -1;
+		$last = ($last < 0 ? 0 : $last);
+		$self->{log}->debug("last is " . $last );
+		$self->_display_data( $last );
+		$self->{inserting} = 0;
+		 if ($self->{rec_spinner}){
+        		$self->{rec_spinner}->SetValue($last+1);
+    		}
+       	} 
+	
+	if ($done) {
+		$self->{changed}=0;
+		$self->_save_subforms;
+		$self->_set_record_status_label;
+	}
+	return $done;
+}
+
+sub _update_fields {
+	my $self = shift;
+	my @pk = ( defined $_[0] ? @{$_[0]} :  $self->{dman}->get_autoinc_primarykeys);
 	#updating a new or an existing record
 	#foreach widget in the form, get the value from the widget and place it in the field unless it's a primary key 
 	#with an autogenerated value
-	my @pk;
 	$self->{log}->debug("cols: " . join(" ", @{$self->{cols}}));
+	my $count_updated=0;
 	foreach my $id (@{$self->{cols}}){
 		next if ($self->{is_ro}->{$id});
 		if (exists  $self->{datawidgets}->{$id}){
-			my $w = $self->{datawidgets}->{$id};
-			$self->{log}->debug("id: " . $id  . " ref: " . $self->{datawidgetsName}->{$id});
-			my $coderef = $getter{ $self->{datawidgetsName}->{$id} };
-			  my  $v  = &$coderef($self, $w, $id );
-			$self->{log}->debug("apply id: $id value: ".  ($v?$v:""));
-
-			@pk = $self->{dman}->get_autoinc_primarykeys;
-
+			#@pk = $self->{dman}->get_autoinc_primarykeys;
 			#if ($id ~~ @pk)  {
 			if (grep /^$id$/, @pk) {
 				$self->{log}->debug("not done because it's a auto incremented pk");
 			} else {
-		
+				my $w = $self->{datawidgets}->{$id};
+				$self->{log}->debug("id: " . $id  . " ref: " . $self->{datawidgetsName}->{$id});
+				my $coderef = $getter{ $self->{datawidgetsName}->{$id} };
+				  my  $v  = &$coderef($self, $w, $id );
+				$self->{log}->debug("apply id: $id value: ".  ($v?$v:""));
 				$v = (defined $v && $v eq "" ? undef : $v);
 				$self->{log}->debug($id  . ": value undef") unless ( defined $v);	
 				# if ( defined $v && ( $id ~~ @{$self->{dates_formatted}})){
@@ -623,13 +665,10 @@ sub apply{
 
 				if ($self->{pos} < -1 ) {
 					$self->{log}->debug("current row pos: " . $self->{dman}->get_row_pos);
-				# $self->{log}->debug("last row pos: " . $self->{dman}->row_count -1);
-				# $self->{dman}->set_row_pos($self->{dman}->get_row_count);
-					$self->{dman}->set_field($id, $v);
-				} else {
 			
-					$self->{dman}->set_field($id, $v);
-				}
+				} 
+				$self->{dman}->set_field($id, $v);
+				$count_updated++;
 				 $self->{log}->debug("done");
 			} # not in @pk
 	   }	# if exists
@@ -638,51 +677,8 @@ sub apply{
 	   }
 	} #foreach
 	#$row->save;
-	$done = $self->{dman}->save;
-	# $self->{log}->debug("nofm: " . $row->nofm);
-	# $self->set_rs_range;
+	return $count_updated;
 
-	#if we were adding a row, put it at the end of the array, and display all the values in the form
-	#ie the value from the user or default value from the database.
-	my %pk_val;	
-
-
-	for my $pk (@pk) {
-	
-		my $value = $self->{dman}->get_field($pk);
-		$pk_val{$pk} = $value;
-		$self->{log}->debug("Primary Key: " . $pk . " value : " . $value);
-	}
-			#push @pk_val, $id
-		
-	if ($done && $self->{after_insert}){
-		my $coderef = $self->{after_insert};
-		&$coderef(undef, \%pk_val );
-	}
-	#if ($done && $self->{pos}<0){
-	if ($done && $self->{inserting}){
-		my $last = $self->{dman}->row_count -1;
-		$last = ($last < 0 ? 0 : $last);
-		$self->{log}->debug("last is " . $last );
-		$self->_display_data( $last );
-		$self->{inserting} = 0;
-		 if ($self->{rec_spinner}){
-		  #	my $last = $self->{dman}->row_count;
-		  #$self->{rec_spinner}->signal_handler_block( $self->{rs_value_changed_signal} );
-		  	#$self->{rec_spinner}->unsusbscribe('PositionChanged',  $self->{rs_value_changed_signal});
-        		$self->{rec_spinner}->SetValue($last+1);
-			#$self->{rec_spinner}->subscribe('PositionChanged', $self->{rs_value_changed_signal} );
-    		}
-       	} else {
-		$self->{changed}=0;
-	
-	}
-	if ($done) {
-		$self->_save_subforms;
-
-		$self->_set_record_status_label;
-	}
-	return $done;
 }
 
 sub next{
